# tlslib.py

<!--- BADGES: START --->
[![CI](https://github.com/trailofbits/tlslib.py/actions/workflows/tests.yml/badge.svg)](https://github.com/trailofbits/tlslib.py/actions/workflows/tests.yml)
[![PyPI version](https://badge.fury.io/py/tlslib.svg)](https://pypi.org/project/tlslib)
[![Packaging status](https://repology.org/badge/tiny-repos/python:tlslib.svg)](https://repology.org/project/python:tlslib/versions)
<!--- BADGES: END --->

An example MVP for the updated PEP 543 proposal

The asyncio example is adapted from the CPython asyncio and falls under the PSF license (see LICENSE.cpython).
